Artist subsystem
****************

The :class:`Artist` class
=========================
.. currentmodule:: spotify

.. class:: Artist

    Artist objects.

    .. method:: is_loaded

        :rtype:     :class:`int`
        :returns:   ``1`` if this artist has been loaded by the client,
            ``0`` if not.

    .. method:: name

        :rtype:     string
        :returns:   the name of the artist

